Description
===========

Ladon is a framework for exposing python methods to several internet service
protocols. Once a method is ladonized it is automatically served through all
the interfaces that your ladon installation contains. Ladon is easily extendable.
Adding a new service interface is as easy as adding a single module containing
a class inheriting the BaseInterface class.

Follow
------

.. image:: http://bazaar.launchpad.net/~ladon-dev-team/ladon/ladon/download/head:/www.png-20110722202829-w6ybxz421j7r86mm-1/www.png
   :target: http://ladonize.org

.. image:: http://ladonize.org/images/launchpad.png
   :target: http://launchpad.net/ladon

.. image:: http://bazaar.launchpad.net/~jakob-simon-gaarde/ladon/trunk/download/head:/twitter.png-20110701083440-xlq4f3vubtovlpoi-1/twitter.png
   :target: http://twitter.com/_ladon_

.. image:: http://bazaar.launchpad.net/~jakob-simon-gaarde/ladon/trunk/download/head:/facebook.png-20110701095223-xtzl2rq29walsbbg-1/facebook.png
   :target: http://www.facebook.com/pages/Ladon/112588282168502?sk=app_2373072738

.. image:: http://bazaar.launchpad.net/~jakob-simon-gaarde/ladon/trunk/download/head:/youtube.png-20110701095217-voe33y3gkg4kv7mo-1/youtube.png
   :target: http://www.youtube.com/playlist?list=PLFD1020FE0CB288FC

Questions
---------
Please direct questions about the Ladon Web Service framework to: https://answers.launchpad.net/ladon

Bugs
----
Report bugs to: https://bugs.launchpad.net/ladon

Contribute
----------

There are plenty of things to do like implementing more interface modules making better service navigation etc. If you are interested in helping out with contributions or even want to join the development team - Go to Ladon's Launchpad page: http://launchpad.net/ladon

What does Ladon mean?
---------------------
Ladon is a serpent-like dragon from Greek mythology which might be given multiple
heads, a hundred in Aristophanes' The Frogs (a passing remark in line 475). each
head might speak with different voices.

.. image:: http://bazaar.launchpad.net/~jakob-simon-gaarde/ladon/trunk/download/head:/ladon2_button.jpg-20110530114736-smbe8ox2zcylfi89-1/ladon2_button.jpg

Like Ladon the dragon has many heads that speak with different voices Ladon the
Web Service has many interfaces that communicate with different protocols. Ladon
the dragon only has one body - users only need to implement their service
classes once.
